@@ -40,13 +40,6 @@ use Lemonldap::NG::Portal::CDA;
 
 my $portal = Lemonldap::NG::Portal::CDA->new(
     {
-
-        # configStorage ADAPT IT as usual
-        configStorage => {
-            type    => 'File',
-            dirName => '/usr/share/doc/lemonldap-ng/examples/conf/',
-        },
-
         # SUBROUTINES OVERLOAD
         # 2 cases :
         # 1 - If LDAP search is not needed (the master SSO gives all
@@ -105,13 +98,13 @@ my $portal = Lemonldap::NG::Portal::CDA->new(
 # Else, we process as usual, but without prompting users with a form
 
 if ( $portal->process() ) {
-    print $portal->header;
+    print $portal->header('text/html; charset=utf8');
     print $portal->start_html;
     print "<h1>Your well authenticated !</h1>";
     print $portal->end_html;
 }
 else {
-    print $portal->header;
+    print $portal->header('text/html; charset=utf8');
     print $portal->start_html;
     print qq#<h2>Authentication failed</h2>
     Portal is not able to recognize you
