@@ -1,7 +1,5 @@
 ## @file
 # Main portal for Lemonldap::NG portal
-#
-# @copy 2005, 2006, 2007, 2008, Xavier Guimard &lt;x.guimard@free.fr&gt;
 
 ## @class
 # Main portal for Lemonldap::NG portal
@@ -22,9 +20,10 @@ use base qw(Lemonldap::NG::Portal::Simple);
 # OVERLOADED SUB #
 ##################
 
-# getConf: all parameters returned by the Lemonldap::NG::Common::Conf object
-#          are copied in $self
-#          See Lemonldap::NG::Common::Conf(3) for more
+## @method boolean getConf(hashRef args)
+# Copy all parameters returned by the Lemonldap::NG::Common::Conf object in $self.
+# @param args hash
+# @return True
 sub getConf {
     my $self = shift;
     my %args;
@@ -40,9 +39,6 @@ sub getConf {
     # the local file system by the handlers. This can be used when
     # configuration is not local (type DBI or SOAP)
     my $tmp = 0;
-    if ( $self->{useLocalCachedConf} and $self->{localStorage} ) {
-        $tmp = $self->localGetConf();
-    }
     unless ($tmp) {
         $self->{lmConf} =
           Lemonldap::NG::Common::Conf->new( $self->{configStorage} )
@@ -57,31 +53,8 @@ sub getConf {
     1;
 }
 
-sub localGetConf {
-    my $self = shift;
-    $self->{_refLocalStorage} ||= $self->localStorageObject;
-    return $self->{_refLocalStorage}->get('conf');
-}
-
-sub localStorageObject {
-    my $self = shift;
-    eval "use " . $self->{localStorage};
-    if ($@) {
-        print STDERR "Unable to load "
-          . $self->{localStorage}
-          . ", local configuration cache is disabled: $@\n";
-        return 0;
-    }
-    my $refLocalStorage;
-    eval '$refLocalStorage = new '
-      . $self->{localStorage}
-      . '($self->{localStorageOptions});';
-    if ($@) {
-        print STDERR "Unable to access to local configuration storage : $@\n";
-        return 0;
-    }
-    return $refLocalStorage;
-}
+## @method list getProtectedSites()
+# @return list list of protected virtual hosts.
 
 # With SharedConf, $locationRules contains a hash table with virtual hosts as
 # keys. So we can use it to know all protected virtual hosts.
@@ -150,7 +123,7 @@ SOAP mode authentication (client) :
   
   my $soap =
     SOAP::Lite->proxy('http://auth.example.com/')
-    ->uri('urn:/Lemonldap::NG::Portal::SharedConf');
+    ->uri('urn:/Lemonldap::NG::Common::::CGI::SOAPService');
   my $r = $soap->getCookies( 'user', 'password' );
   
   # Catch SOAP errors
