@@ -1,9 +1,7 @@
-## @file
+##@file
 # Base package for Lemonldap::NG portal
-#
-# @copy 2005, 2006, 2007, 2008, Xavier Guimard &lt;x.guimard@free.fr&gt;
 
-## @class
+##@class
 # Base class for Lemonldap::NG portal
 package Lemonldap::NG::Portal::Simple;
 
@@ -20,7 +18,7 @@ require POSIX;
 use Lemonldap::NG::Portal::_i18n;
 use Safe;
 
-our $VERSION = '0.86';
+our $VERSION = '0.87';
 
 use base qw(Lemonldap::NG::Common::CGI Exporter);
 our @ISA;
@@ -78,15 +76,15 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our $safe;
 our $self;    # Safe cannot share a variable declared with my
 
-## @cmethod new($args)
+##@cmethod Lemonldap::NG::Portal::Simple new(hashRef args)
 # Class constructor.
-# @param args hash reference
-# @return Lemonldap::NG::Portal object
+#@param args hash reference
+#@return Lemonldap::NG::Portal::Simple object
 sub new {
     binmode( STDOUT, ":utf8" );
     my $class = shift;
     return $class if ( ref($class) );
-    $self = $class->SUPER::new();
+    my $self = $class->SUPER::new();
     $self->getConf(@_)
       or $self->abort( "Configuration error",
         "Unable to get configuration: $Lemonldap::NG::Common::Conf::msg" );
@@ -106,8 +104,10 @@ sub new {
     $self->{authentication} ||= 'LDAP';
     $self->{userDB}         ||= 'LDAP';
     $self->{authentication} =~ s/^ldap/LDAP/;
-    $self->{mustRedirect} =
-      ( $ENV{REQUEST_METHOD} eq 'POST' or $self->param('logout') ) ? 1 : 0;
+    $self->{mustRedirect} = (
+        ( $ENV{REQUEST_METHOD} eq 'POST' and not $self->param('newpassword') )
+          or $self->param('logout')
+    ) ? 1 : 0;
 
     # Authentication module is required and has to be in @ISA
     foreach (qw(authentication userDB)) {
@@ -127,9 +127,6 @@ sub new {
         my %h = split( /\s*[=;]\s*/, $tmp ) if ($tmp);
         %$self = ( %h, %$self );
     }
-    if ( $self->{notification} ) {
-        require Lemonldap::NG::Common::Notification;
-    }
     if ( $self->{Soap} ) {
         require SOAP::Lite;
         $self->soapTest("${class}::getCookies ${class}::error");
@@ -137,9 +134,10 @@ sub new {
     return $self;
 }
 
-## @method protected getConf($args)
+##@method protected boolean getConf(hashRef args)
 # Copy all parameters in caller object.
-# @param args hash-ref
+#@param args hash-ref
+#@return True
 sub getConf {
     my ($self) = shift;
     my %args;
@@ -153,10 +151,10 @@ sub getConf {
     1;
 }
 
-## @method protected string error($lang)
+##@method string error(string lang)
 # error calls Portal/_i18n.pm to display error in the wanted language.
-# @param lang optional (browser language is used instead)
-# @return error message
+#@param $lang optional (browser language is used instead)
+#@return error message
 sub error {
     my $self = shift;
     my $lang = shift || $ENV{HTTP_ACCEPT_LANGUAGE};
@@ -164,8 +162,10 @@ sub error {
     return &Lemonldap::NG::Portal::_i18n::error( $code, $lang );
 }
 
-## @method int error_type()
+##@method string error_type(int code)
 # error_type tells if error is positive, warning or negative
+# @param $code Lemonldap::NG error code
+# @return "positive", "warning" or "negative"
 sub error_type {
     my $self = shift;
     my $code = shift || $self->{error};
@@ -203,11 +203,12 @@ sub error_type {
     return "negative";
 }
 
-## @method translate_template($$text_ref, $lang)
+##@method void translate_template(string text_ref, string lang)
 # translate_template is used as an HTML::Template filter to tranlate strings in
 # the wanted language
-# @param text_ref reference to the string to translate
-# @param lang optionnal language wanted. Falls to browser language instead.
+#@param text_ref reference to the string to translate
+#@param lang optionnal language wanted. Falls to browser language instead.
+#@return
 sub translate_template {
     my $self     = shift;
     my $text_ref = shift;
@@ -229,7 +230,8 @@ sub translate_template {
     }
 }
 
-# CGI.pm overload to add Lemonldap::NG cookie
+##@method void header()
+# Overload CGI::header() to add Lemonldap::NG cookie.
 sub header {
     my $self = shift;
     if ( $self->{cookie} ) {
@@ -240,7 +242,8 @@ sub header {
     }
 }
 
-# CGI.pm overload to add Lemonldap::NG cookie
+##@method void redirect()
+# Overload CGI::redirect() to add Lemonldap::NG cookie.
 sub redirect {
     my $self = shift;
     if ( $self->{cookie} ) {
@@ -251,8 +254,10 @@ sub redirect {
     }
 }
 
-# getSessionInfo
-# Read session and store it in $self
+##@method void getSessionInfo()
+# Read cookie and set session info.
+# If lemonldap cookie exists, reads it and search session. If the session is
+# available, store it in $self->{sessionInfo}
 sub getSessionInfo {
     my $self    = shift;
     my %cookies = fetch CGI::Cookie;
@@ -285,8 +290,12 @@ sub getSessionInfo {
 
 }
 
-# updateSession
-# Update information stored in session
+##@method void updateSession(hashRef infos)
+# Update session stored.
+# If lemonldap cookie exists, reads it and search session. If the session is
+# available, update datas with $info.
+#@param $infos hash
+
 # TODO: update all caches
 sub updateSession {
     my $self    = shift;
@@ -321,13 +330,19 @@ sub updateSession {
 
 }
 
-# Externalise functions execution
+##@method protected int _subProcess(array @subs)
+# Execute methods until an error is returned.
+# If $self->{$sub} exists, launch it, else launch $self->$sub
+#@param @subs array list of subroutines
+#@return Lemonldap::NG::Portal error
 sub _subProcess {
     my $self = shift;
     my @subs = @_;
     my $err  = undef;
 
     foreach my $sub (@subs) {
+
+        #print STDERR "DEBUG : $sub\n";
         if ( $self->{$sub} ) {
             last if ( $err = &{ $self->{$sub} }($self) );
         }
@@ -338,7 +353,10 @@ sub _subProcess {
 
     return $err;
 }
-
+##@method protected void updateStatus()
+# Inform status mechanism module.
+# If an handler is launched on the same server with "status=>1", inform the
+# status module with the result (portal error).
 sub updateStatus {
     my ($self) = @_;
     print $Lemonldap::NG::Handler::Simple::statusPipe (
@@ -348,6 +366,8 @@ sub updateStatus {
       if ($Lemonldap::NG::Handler::Simple::statusPipe);
 }
 
+##@method protected Lemonldap::NG::Portal::Notification notification()
+#@return Lemonldap::NG::Portal::Notification object
 sub notification {
     my ($self) = @_;
     return $self->{_notification};
@@ -355,13 +375,15 @@ sub notification {
 
 ##@method string get_url()
 # check url against XSS attacks
+# @return url parameter if good, nothing else.
 sub get_url {
     my ($self) = @_;
+    return unless $self->param('url');
     return if ( $self->param('url') =~ m#[^A-Za-z0-9\+/=]# );
     return $self->param('url');
 }
 
-##@method private object safe()
+##@method private Safe safe()
 # Provide the security jail.
 #@return Safe object
 sub safe {
@@ -384,7 +406,7 @@ sub safe {
             }";
         print STDERR $@ if ($@);
     }
-    $safe->share( '$self', '&encode_base64', @t );
+    $safe->share( '&encode_base64', @t );
     return $safe;
 }
 
@@ -392,14 +414,14 @@ sub safe {
 # SOAP subroutines #
 ####################
 
-##@method string SOAP::Data getCookies($user,$password)
+##@method SOAP::Data getCookies(string user,string password)
 # Called in SOAP context, returns cookies in an array.
 # This subroutine works only for portals working with user and password
 #@param user uid
 #@param password password
 #@return session => { error => code , cookies => { cookieName1 => value ,... } }
 sub getCookies {
-    my $class = shift;
+    my $self = shift;
     $self->{error} = PE_OK;
     ( $self->{user}, $self->{password} ) = ( shift, shift );
     unless ( $self->{user} && $self->{password} ) {
@@ -438,7 +460,6 @@ sub getCookies {
 #  - authentication module : extractFormInfo, setAuthSessionInfo, authenticate
 #  - user database module  : getUser, setSessionInfo
 #@return 1 if user is all is OK, 0 if session isn't created or a notification has to be done
-
 sub process {
     my ($self) = @_;
     $self->{error} = PE_OK;
@@ -452,9 +473,9 @@ sub process {
     return ( ( $self->{error} > 0 ) ? 0 : 1 );
 }
 
-## @method error_code checkNotifBack()
+##@method int checkNotifBack()
 # 1) Checks if a message has to be notified to the connected user.
-# @return error code
+#@return Lemonldap::NG::Portal error code
 sub checkNotifBack {
     my $self = shift;
 
@@ -462,9 +483,9 @@ sub checkNotifBack {
     PE_OK;
 }
 
-## @method error_code controlUrlOrigin()
+##@method int controlUrlOrigin()
 # 2) If the user was redirected here, loads 'url' parameter.
-# @return error_code
+#@return Lemonldap::NG::Portal constant
 sub controlUrlOrigin {
     my $self = shift;
     if ( $self->param('url') ) {
@@ -478,7 +499,8 @@ sub controlUrlOrigin {
         # REJECT [\0<'"`] in URL or encoded '%' and non protected hosts
         if (
             $self->{urldc} =~ /(?:\0|<|'|"|`|\%(?:00|25|3C|22|27|2C))/
-            or ( $self->{urldc} !~ m#^https?://(?:$self->{reVHosts}|(?:[^/]*)?$self->{domain})(?:/.*)?$#
+            or ( $self->{urldc} !~
+m#^https?://(?:$self->{reVHosts}|(?:[^/]*)?$self->{domain})(?::\d+)?(?:/.*)?$#
                 and not $self->param('logout') )
           )
         {
@@ -492,14 +514,14 @@ sub controlUrlOrigin {
     PE_OK;
 }
 
-## @method error_code controlExistingSession()
+##@method int controlExistingSession()
 # 3) Control existing sessions.
 # To overload to control what to do with existing sessions.
 # what to do with existing sessions ?
 #       - nothing: user is authenticated and process returns true (default)
 #       - delete and create a new session (not implemented)
 #       - re-authentication (set existingSession => sub{PE_OK})
-# @return error_code
+#@return Lemonldap::NG::Portal constant
 sub controlExistingSession {
     my $self    = shift;
     my %cookies = fetch CGI::Cookie;
@@ -591,14 +613,15 @@ sub existingSession {
 # 9. setSessionInfo() : must be implemented in User* module:
 #                            * store exported datas in $self->{sessionInfo}
 
-## @method error_code setMacro()
-# 10) macro mechanism:
+##@method int setMacro()
+# 10) macro mechanism.
 #                  * store macro results in $self->{sessionInfo}
-# @return error_code
+#@return Lemonldap::NG::Portal constant
 sub setMacros {
     local $self = shift;
     $self->abort( __PACKAGE__ . ": Unable to get configuration" )
       unless ( $self->getConf(@_) );
+    $self->safe->share('$self');
     while ( my ( $n, $e ) = each( %{ $self->{macros} } ) ) {
         $e =~ s/\$(\w+)/\$self->{sessionInfo}->{$1}/g;
         $self->{sessionInfo}->{$n} = $self->safe->reval($e);
@@ -606,19 +629,17 @@ sub setMacros {
     PE_OK;
 }
 
-## @method error_code setGroups()
-# 11) groups mechanism:
+##@method int setGroups()
+# 11) groups mechanism.
 #                    * store all groups name that the user match in
 #                      $self->{sessionInfo}->{groups}
+#@return Lemonldap::NG::Portal constant
 sub setGroups {
     local $self = shift;
     my $groups;
-
-    #foreach ( keys %{ $self->{groups} } ) {
+    $self->safe->share('$self');
     while ( my ( $group, $expr ) = each %{ $self->{groups} } ) {
         $expr =~ s/\$(\w+)/\$self->{sessionInfo}->{$1}/g;
-
-        # TODO : custom Functions
         $groups .= "$group " if ( $self->safe->reval($expr) );
     }
     if ( $self->{ldapGroupBase} ) {
@@ -644,10 +665,11 @@ sub setGroups {
 # 12. authenticate() : must be implemented in Auth* module:
 #                       * authenticate the user if not done before
 
-## @method error_code store()
-# 13. Now, the user is known, authenticated and session variable are evaluated.
+##@method int store()
+# 13) Store user's datas in sessions database.
+#     Now, the user is known, authenticated and session variable are evaluated.
 #     It's time to store his parameters with Apache::Session::* module
-# @return error_code
+#@return Lemonldap::NG::Portal constant
 sub store {
     my ($self) = @_;
     my %h;
@@ -666,9 +688,9 @@ sub store {
     PE_OK;
 }
 
-## @method error_code buildCookie()
-# 14. If all is done, we build the Lemonldap::NG cookie
-# @return error_code
+##@method int buildCookie()
+# 14) Build the Lemonldap::NG cookie.
+#@return Lemonldap::NG::Portal constant
 sub buildCookie {
     my $self = shift;
     push @{ $self->{cookie} },
@@ -683,10 +705,11 @@ sub buildCookie {
     PE_OK;
 }
 
-## @method error_code log()
-# 15. By default, nothing is logged. Users actions are logged on applications.
-#     It's easy to override this in the contructor :
-#       my $portal = new Lemonldap::NG::Portal ( {
+##@method int log()
+# 15) Log authentication action.
+# By default, nothing is logged. Users actions are logged on applications.
+# It's easy to override this in the contructor :
+# my $portal = new Lemonldap::NG::Portal ( {
 #                    ...
 #                    log => sub {use Sys::Syslog; syslog;
 #                                openlog("Portal $$", 'ndelay', 'auth');
@@ -694,14 +717,14 @@ sub buildCookie {
 #                               },
 #                   ...
 #                 } );
-# @return error_code
+#@return Lemonldap::NG::Portal constant
 sub log {
     PE_OK;
 }
 
-## @method error_code checkNotification()
-# 16. Check if messages has to be notified
-# @return error_code
+##@method int checkNotification()
+# 16) Check if messages has to be notified.
+#@return Lemonldap::NG::Portal constant
 sub checkNotification {
     my $self = shift;
     if ( $self->{notification} ) {
@@ -723,10 +746,10 @@ sub checkNotification {
     return PE_OK;
 }
 
-## @method error_code autoRedirect()
+##@method int autoRedirect()
 # 17) If the user was redirected to the portal, we will now redirect him
-#     to the requested URL
-# @return error_code
+#     to the requested URL.
+#@return Lemonldap::NG::Portal constant
 sub autoRedirect {
     my $self = shift;
     if ( my $u = $self->{urldc} ) {
@@ -826,7 +849,7 @@ SOAP mode authentication (client) :
   
   my $soap =
     SOAP::Lite->proxy('http://auth.example.com/')
-    ->uri('urn:/Lemonldap::NG::Portal::SharedConf');
+    ->uri('urn:/Lemonldap::NG::Common::::CGI::SOAPService');
   my $r = $soap->getCookies( 'user', 'password' );
   
   # Catch SOAP errors
